
Komut Arayüz Referansı
================================================
Referans olması amacıyla tüm komutların kod dokümantasyonları eklenmiştir.


Omnitron Komutları
______________________________

Hata Raporu
~~~~~~~~~~~~~~

.. autoclass:: channel_app.omnitron.commands.error_reports.CreateAddressErrorReports
    :members:

|

Batch Request
~~~~~~~~~~~~~~~~

.. autoclass:: channel_app.omnitron.commands.batch_requests.GetBatchRequests
    :members:

|

Integration Action
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: channel_app.omnitron.commands.integration_actions.CreateIntegrationActions
    :members:

|

.. autoclass:: channel_app.omnitron.commands.integration_actions.GetIntegrationActionsWithObjectId
    :members:

|

.. autoclass:: channel_app.omnitron.commands.integration_actions.GetIntegrationActionsWithRemoteId
    :members:

|

Sipariş
~~~~~~~~~~~~~~

.. autoclass:: channel_app.omnitron.commands.orders.addresses.GetOrCreateAddress
    :members:

|

.. autoclass:: channel_app.omnitron.commands.orders.cargo_companies.GetCargoCompany
    :members:

|

.. autoclass:: channel_app.omnitron.commands.orders.customers.GetOrCreateCustomer
    :members:

|

.. autoclass:: channel_app.omnitron.commands.orders.orders.CreateOrders
    :members:

|

.. autoclass:: channel_app.omnitron.commands.orders.orders.CreateOrderShippingInfo
    :members:

|

.. autoclass:: channel_app.omnitron.commands.orders.orders.GetOrders
    :members:

|

.. autoclass:: channel_app.omnitron.commands.orders.orders.ProcessOrderBatchRequests
    :members:

|

Fiyat
~~~~~~~~~~~~

.. autoclass:: channel_app.omnitron.commands.product_prices.GetUpdatedProductPrices
    :members:

|

.. autoclass:: channel_app.omnitron.commands.product_prices.ProcessPriceBatchRequests
    :members:

|

.. autoclass:: channel_app.omnitron.commands.product_prices.GetInsertedProductPrices
    :members:

|


Stok
~~~~~~~~

.. autoclass:: channel_app.omnitron.commands.product_stocks.GetUpdatedProductStocks
    :members:

|

.. autoclass:: channel_app.omnitron.commands.product_stocks.ProcessStockBatchRequests
    :members:

|

.. autoclass:: channel_app.omnitron.commands.product_stocks.GetInsertedProductStocks
    :members:

|


Ürün
~~~~~~~~~~~~~

.. autoclass:: channel_app.omnitron.commands.products.GetInsertedProducts
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.GetUpdatedProducts
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.ProcessProductBatchRequests
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.GetDeletedProducts
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.ProcessDeletedProductBatchRequests
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.GetMappedProducts
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.GetProductPrices
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.GetProductImages
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.GetProductStocks
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.GetInsertedOrUpdatedProducts
    :members:

|

.. autoclass:: channel_app.omnitron.commands.products.GetProductCategoryNodes
    :members:

|


Kurulum
~~~~~~~~~

.. autoclass:: channel_app.omnitron.commands.setup.CreateOrUpdateCategoryTreeAndNodes
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.CreateOrUpdateCategoryAttributes
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.GetCategoryIds
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.CreateOrUpdateChannelAttributeSet
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.GetOrCreateChannelAttributeSetConfig
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.CreateOrUpdateChannelAttribute
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.CreateOrUpdateChannelAttributeConfig
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.CreateOrUpdateChannelAttributeValue
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.GetOrCreateChannelAttributeValueConfig
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.AsyncCreateOrUpdateCategoryAttributes
    :members:

|

.. autoclass:: channel_app.omnitron.commands.setup.GetOrCreateChannelAttributeSchema
    :members:


Satış Kanalı Komutları
______________________________


Fiyat
~~~~~~

.. autoclass:: channel_app.channel.commands.product_prices.CheckPrices
    :members:

|

.. autoclass:: channel_app.channel.commands.product_prices.SendInsertedPrices
    :members:

|

.. autoclass:: channel_app.channel.commands.product_prices.SendUpdatedPrices
    :members:

|

Stok
~~~~~~~~~~~

.. autoclass:: channel_app.channel.commands.product_stocks.SendUpdatedStocks
    :members:

|

.. autoclass:: channel_app.channel.commands.product_stocks.CheckStocks
    :members:

|

.. autoclass:: channel_app.channel.commands.product_stocks.SendInsertedStocks
    :members:

|

Ürün
~~~~~~~~~~~~

.. autoclass:: channel_app.channel.commands.products.SendInsertedProducts
    :members:

|

.. autoclass:: channel_app.channel.commands.products.CheckProducts
    :members:

|

.. autoclass:: channel_app.channel.commands.products.CheckDeletedProducts
    :members:

|

.. autoclass:: channel_app.channel.commands.products.SendUpdatedProducts
    :members:

|

.. autoclass:: channel_app.channel.commands.products.SendDeletedProducts
    :members:

|


Kurulum
~~~~~~~~~~~

.. autoclass:: channel_app.channel.commands.setup.GetCategoryTreeAndNodes
    :members:

|

.. autoclass:: channel_app.channel.commands.setup.GetCategoryAttributes
    :members:



